import axios from 'axios'

const url = '/eiru_purchases/new'

const state = {
    products: {
        default: [],
        values: []
    },
    filteredProducts: {
        default: [],
        values: []
    },
    productWithVariant: {
        default: null,
        value: null
    },
    showProductForm: {
        default: false,
        value: false
    }
}

const getters = {
    /**
     * 
     * @param {*} state 
     */
    products(state) {
        return state.products.values
    },
    /**
     * 
     * @param {*} state 
     */
    visibleProducts(state) {
        return state.filteredProducts.values.length === 0 ? state.products.values : state.filteredProducts.values
    },
    /**
     * 
     * @param {*} state 
     */
    productWithVariant(state) {
        return state.productWithVariant.value
    },
    /**
     * 
     * @param {*} state 
     */
    showProductForm(state) {
        return state.showProductForm.value
    }
}

const mutations = {
    /**
     * 
     * @param {*} state 
     * @param {*} payload 
     */
    setProducts(state, payload) {
        state.products.values = [...payload]
    },
    /**
     * 
     * @param {*} state 
     * @param {*} payload 
     */
    setProductWithVariant(state, payload) {
        state.productWithVariant.value = value
    },
    /**
     * 
     * @param {*} state 
     * @param {*} payload 
     */
    setFilteredProducts(state, payload) {
        state.filteredProducts.values = [...payload]
    },
    /**
     * 
     * @param {*} state 
     * @param {*} payload 
     */
    setShowProductForm(state, payload) {
        state.showProductForm.value = !!payload
    },
    /**
     * 
     * @param {*} state 
     * @param {*} payload 
     */
    addProduct(state, payload) {
        state.products.values = [payload, ...state.products.values]
    }
}

const actions = {
    /**
     * 
     * @param {*} param0 
     * @param {*} payload 
     */
    selectProduct({ commit, dispatch }, payload) {
        if (payload.variantCount > 1) {
            commit('setProductWithVariant', payload)
            return
        }

        dispatch('addToCart', payload.variants[0])
    },
    /**
     * 
     * @param {*} param0 
     * @param {*} payload 
     */
    filterProducts({ commit }, payload) {
        commit('setFilteredProducts', payload)
    },
    /**
     * 
     * @param {*} param0 
     * @param {*} payload 
     */
    selectProductVariant({ commit, dispatch }, payload) {
        commit('setProductVariant', null)

        if (!payload) return

        dispatch('addToCart', payload)
    },
    /**
     * 
     * @param {*} param0 
     * @param {*} payload 
     */
    showProductForm({ commit }) {
        commit('setShowProductForm', true)
    },
    /**
     * 
     * @param {*} param0 
     * @param {*} payload 
     */
    hideProductForm({ commit }) {
        commit('setShowProductForm', false)
    },
    /**
     * 
     * @param {*} param0 
     * @param {*} payload 
     */
    submitProduct({ dispatch }, payload) {
        if (payload) {
            if (!payload.name || !payload.price) {
                dispatch('notify', 'Complete los campos para guardar')
                return
            }

            dispatch('createProduct', payload)
        }

        dispatch('hideProductForm')
    },
    /**
     * 
     * @param {*} param0 
     * @param {*} payload 
     */
    addProduct({ commit }, payload) {
        commit('addProduct', payload)
    }
}

export default {
    state,
    getters,
    mutations,
    actions
}